@@ -3,6 +3,9 @@
 
 from __future__ import absolute_import
 
+import types
+import locale
+
 from twisted.python import usage, log
 from twisted.internet import reactor, defer
 from zope.interface import implements
@@ -49,6 +52,7 @@ class CliApp:
         else:
             frm, to = 'it', 'en'
         for word in self.config['words']:
+            word = word.decode(locale.getlocale()[1])
             d = self.translator.translate(word, frm, to)
             d.addCallbacks(self.write, log.err)
             dl.append(d)
