@@ -3,6 +3,8 @@
 
 from __future__ import absolute_import
 
+import types
+
 from twisted.internet import gtk2reactor
 gtk2reactor.install()
 from twisted.internet import reactor
@@ -84,7 +86,8 @@ class MainWindow(gtk.Window):
         self.show_all()
 
     def insert(self, li):
-        map(self.store.append, li)
+        for i, row in enumerate(li):
+            self.store.insert(i, row)
 
     def onKeyReleased(self, widget, event, data=None):
         if event.type == gtk.gdk.KEY_RELEASE and \
@@ -97,6 +100,8 @@ class MainWindow(gtk.Window):
 
     def onTranslate(self):
         word = self.entry.get_text()
+        if type(word) is not types.UnicodeType:
+            word = unicode(word, 'utf8')
         lang = self.lang_cb.get_active_text()
         frm, to = self.map.getCodes(lang)
         d = self.translator.translate(word, frm, to)
