@@ -5,6 +5,9 @@
 from __future__ import absolute_import
 
 import sys
+import locale
+locale.setlocale(locale.LC_ALL, '')
+
 from twisted.python import usage
 from twisted.plugin import getPlugins
 
