@@ -3,6 +3,7 @@
 
 from __future__ import absolute_import
 
+import types
 import Tkinter as Tk
 
 from twisted.python import usage, log
@@ -72,6 +73,8 @@ class TkTranslatorWindow(Tk.Tk):
 
     def onTranslate(self):
         word = self.wordEtr.get()
+        if type(word) is not types.UnicodeType:
+            word = unicode(word)
         frm, to = self.getLanguages()
         d = self.translator.translate(word, frm, to)
         d.addCallback(self.insert)
@@ -81,8 +84,8 @@ class TkTranslatorWindow(Tk.Tk):
         return self.map.getCodes(self.langstr.get())
 
     def insert(self, li):
-        for word, trans in li:
-            self.listbox.insert(Tk.END, '%s: %s' % (word, trans))
+        for i, row in enumerate(li):
+            self.listbox.insert(i, '%s: %s' % row)
 
 
 class TkApp(object):
