@@ -4,6 +4,7 @@
 
 from __future__ import absolute_import
 
+import unicodedata
 try:
     from itertools import permutations  # python 2.6
 except ImportError:
@@ -75,3 +76,9 @@ class LanguageMap(object):
 
     def getCodes(self, label):
         return self._map[label]
+
+
+def stripAccents(s):
+   return ''.join(c for c in unicodedata.normalize('NFD', s)
+                  if not unicodedata.combining(c))
+
